==> Bibulus-0.14.tar.gz: Bibulus-0.14/Bibulus/el.pm <==
package Bibulus::el;

use strict;
use warnings;
use Carp;

# This file is not finished.  Please help!

sub populate {
  my $self = shift;
  $self->{LANGTEXT}{el}{and} ||= 'και';
  $self->{LANGTEXT}{el}{in} ||= 'στο';
  $self->{LANGTEXT}{el}{month}{1}{full} ||= 'Ιανουάριος';
  $self->{LANGTEXT}{el}{month}{2}{full} ||= 'Φεβρουάριος';
  $self->{LANGTEXT}{el}{month}{3}{full} ||= 'Μάρτιος';
  $self->{LANGTEXT}{el}{month}{4}{full} ||= 'Απρίλιος';
  $self->{LANGTEXT}{el}{month}{5}{full} ||= 'Μάιος';
  $self->{LANGTEXT}{el}{month}{6}{full} ||= 'Ιούνιος';
  $self->{LANGTEXT}{el}{month}{7}{full} ||= 'Ιούλιος';
  $self->{LANGTEXT}{el}{month}{8}{full} ||= 'Αύγουστος';
  $self->{LANGTEXT}{el}{month}{9}{full} ||= 'Σεπτέμβριος';
  $self->{LANGTEXT}{el}{month}{10}{full} ||= 'Οκτώβριος';
  $self->{LANGTEXT}{el}{month}{11}{full} ||= 'Νοέμβριος';
  $self->{LANGTEXT}{el}{month}{12}{full} ||= 'Δεκέμβριος';

  $self->{LANGINIT}{el} = 1;
}

1;
__END__

=head1 NAME

Bibulus::Lang::el - Bibulus support for Greek

=head2 EXPORT

None.

=head1 SEE ALSO

F<Bibulus>, F<Bibulus::lang>.

The homepage is
L<http://www.nongnu.org/bibulus/>.

=head1 AUTHOR

Thomas M. Widmann, L<twid@cpan.org>

=head1 COPYRIGHT AND LICENSE

Copyright 2003 by Thomas M. Widmann

This module is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
USA.

=cut

==> Bibulus-0.49.tar.gz: Bibulus-0.49/Bibulus/el.pm <==
package Bibulus::el;

use strict;
use warnings;
use Carp;

# This file is not finished.  Please help!

sub populate {
  my $self = shift;
  $self->{LANGTEXT}{el}{and} ||= 'και';
  $self->{LANGTEXT}{el}{in} ||= 'στο';
  $self->{LANGTEXT}{el}{month1} ||= 'Ιανουάριος';
  $self->{LANGTEXT}{el}{month2} ||= 'Φεβρουάριος';
  $self->{LANGTEXT}{el}{month3} ||= 'Μάρτιος';
  $self->{LANGTEXT}{el}{month4} ||= 'Απρίλιος';
  $self->{LANGTEXT}{el}{month5} ||= 'Μάιος';
  $self->{LANGTEXT}{el}{month6} ||= 'Ιούνιος';
  $self->{LANGTEXT}{el}{month7} ||= 'Ιούλιος';
  $self->{LANGTEXT}{el}{month8} ||= 'Αύγουστος';
  $self->{LANGTEXT}{el}{month9} ||= 'Σεπτέμβριος';
  $self->{LANGTEXT}{el}{month10} ||= 'Οκτώβριος';
  $self->{LANGTEXT}{el}{month11} ||= 'Νοέμβριος';
  $self->{LANGTEXT}{el}{month12} ||= 'Δεκέμβριος';

  $self->{LANGINIT}{el} = 1;
}

1;
__END__

=head1 NAME

Bibulus::Lang::el - Bibulus support for Greek

=head2 EXPORT

None.

=head1 SEE ALSO

F<Bibulus>, F<Bibulus::lang>.

The homepage is
L<http://www.nongnu.org/bibulus/>.

=head1 AUTHOR

Thomas M. Widmann, L<twid@cpan.org>

=head1 COPYRIGHT AND LICENSE

Copyright 2003 by Thomas M. Widmann

This module is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
USA.

=cut
